#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_COMMA_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_COMMA_HPP_INCLUDED

#include <boost/simd/operator/include/functions/scalar/comma.hpp>

#endif
